@@ -168,6 +168,8 @@ pub enum TeleportFeatures {
     NewFile = 0x01,
     Delta = 0x02,
     Overwrite = 0x04,
+    Backup = 0x08,
+    Rename = 0x10,
 }
 
 impl TeleportInit {
